
Quick access to the [Textual demo](https://github.com/textualize/textual)

The Textual demo is bundled with the Textual library.
This project bundles that app so that it is a single command away.
      
If you have [uv](https://docs.astral.sh/uv/guides/tools/) installed:

```
uvx textual-demo
```

If you have [pipx](https://pipx.pypa.io/stable/) installed:

```
pipx run textual-demo
```

## Was that fun? 

Head over to [Textual](https://github.com/textualize/textual/) to start building!


## Video 
     
https://github.com/user-attachments/assets/9e802aa1-c3a4-42bd-9669-66cba205cc74
     




